@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2016-01-21'; # DATE
-our $VERSION = '1.33'; # VERSION
+our $DATE = '2016-01-22'; # DATE
+our $VERSION = '1.34'; # VERSION
 
 use 5.010001;
 use strict;
@@ -958,6 +958,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                     write_text("$tempdir/infile-invalid-json", qq({}\n{\n));
                     write_text("$tempdir/infile-int", qq(1\n3\n5\n));
                     write_text("$tempdir/infile-invalid-int", qq(1\nx\n5\n));
+                    write_text("$tempdir/infile-invalid-words", qq(word1\nword2\nnot a word\n));
                 },
                 tests => [
                     {
@@ -988,6 +989,15 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         argv        => ["$tempdir/infile-invalid-json"],
                         exit_code => 200,
                     },
+                    {
+                        tags        => ['streaming', 'streaming-input', 'validate-streaming-input'],
+                        name        => 'stream input (json stream, error in record #2)', # test that each record is chomp-ed
+                        gen_args    => {url => '/Perinci/Examples/Stream/num_words'},
+                        inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
+                        argv        => ["$tempdir/infile-invalid-words"],
+                        exit_code_like => qr/[1-9]/,
+                        stdout_like => qr/fails validation/,
+                    },
                     {
                         tags        => ['streaming', 'streaming-input', 'streaming-result'],
                         name        => "stream input+result (simple types)",
@@ -1021,6 +1031,22 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                                              ^\Q{"num":3}\E\n
                                          /mx,
                     },
+                    {
+                        tags        => ['streaming', 'streaming-result', 'validate-streaming-result'],
+                        name        => "stream result (simple types)",
+                        gen_args    => {url => '/Perinci/Examples/Stream/word_err'},
+                        inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
+                        argv        => ["-n", 9],
+                    },
+                    {
+                        tags        => ['streaming', 'streaming-result', 'validate-streaming-result'],
+                        name        => "stream result (simple types, error in output record)",
+                        gen_args    => {url => '/Perinci/Examples/Stream/word_err'},
+                        inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
+                        argv        => ["-n", 10],
+                        exit_code_like => qr/[1-9]/,
+                        stderr_like => qr/fails validation/,
+                    },
                 ],
             }, # streaming
 
@@ -1420,7 +1446,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.33 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-01-21.
+This document describes version 1.34 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-01-22.
 
 =head1 FUNCTIONS
 
